call_geolocator: Call gelocator for one address
Description
Call gelocator for one address
Usage
call_geolocator(street, city, state)
Arguments
street
A character string indicating a street name and number
city
A character string indicating a city
state
A two-digit character string with a state postal code
Value
A character string representing the Census block of the supplied
address.
importFrom utils URLencode
importFrom httr GET stop_for_status