Construct a geography request string from a FIPS Code
get_geo_url(geoid, allgeos)A character string with a FIPS code, between 2 and 15 digits long.
(optional) A string identifying the type of geography for
which to collect data within the the requested geoids. Must be one
of c('co', 'tr', 'bg', 'bl'). For instance, if allgeos =
"bg", will return all block groups within the given geoids.
A string with the FIPS formatted for an API request.